csep.core.catalogs.CSEPCatalog.spatial\_magnitude\_counts
=========================================================

.. currentmodule:: csep.core.catalogs

.. automethod:: CSEPCatalog.spatial_magnitude_counts